""" Module defining constants """

# string constants for processor names
TOKENIZE = 'tokenize'
MWT = 'mwt'
POS = 'pos'
LEMMA = 'lemma'
DEPPARSE = 'depparse'
NER = 'ner'
SRL = 'srl'
SENTIMENT = 'sentiment'
